<?php
/*
 * The MIT License
 *
 * Copyright 2019 ismitka.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

class WP_MeteoSidebar_DataProvider {

    /**
     * @param string $location
     * @return SimpleXMLElement
     */
    private function getForecast($location) {
        try {
            $dir = dirname(__FILE__) . "/data";
            if(!file_exists($dir)) {
                mkdir($dir);
            }
            $dataFile = "{$dir}/data.json";
            $dataRequest = $location . "/forecast_hour_by_hour";
            $hash = md5($dataRequest);
            $resultFile = "{$dir}/{$hash}.xml";

            $data = array ();
            if(file_exists($dataFile)) {
                $data = json_decode(file_get_contents($dataFile), true);
                if($data [$hash] && file_exists($resultFile)) {
                    if($data [$hash] > (time() - 600)) {
                        $result = file_get_contents($resultFile);
                    }
                }
            }

            if(!$result) {
                file_put_contents($resultFile, file_get_contents("http://www.yr.no/place/{$dataRequest}.xml"));
                $data [$hash] = time();
                file_put_contents($dataFile, json_encode($data));
                $result = file_get_contents($resultFile);
            }
            return new SimpleXMLElement($result);
        } catch(Exception $e) {
            print $e;
        }
    }

    public function getWeatherData($value) {
        $forecast = $this->getForecast($value);
        foreach($forecast->forecast->tabular->time as $f) {
            /* @var $symbol SimpleXMLElement */
            $symbol = $f->symbol;
            $symbolUrl = "http://www.yr.no/grafikk/sym/v2016/png/38/{$symbol->attributes()->var->__toString()}.png";
            /* @var $temp SimpleXMLElement */
            $temp = $f->temperature;
            $tempC = $temp->attributes()->value->__toString();
            $link = "http://www.yr.no/place/{$value}";

            return [
                "symbolUrl" => $symbolUrl,
                "symbolCode" => $symbol->attributes()->var->__toString(),
                "temperature" => "{$tempC} &deg;C",
                "link" => $link
            ];
        }
    }
}

$provider = new WP_MeteoSidebar_DataProvider();
print json_encode($provider->getWeatherData($_POST["placeId"]));