<?php

/**
 * Plugin Name: Meteo Sidebar Widget
 * Plugin URI: http://www.smitka.net/meteo-sidebar
 * Description: Show current forecast of given place
 * Version: 1.0
 * Author: Ivan Smitka
 * Author URI: http://www.smitka.net
 * License: The MIT License
 *
 * Copyright 2016 ismitka.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
class WP_MeteoSidebar {

    public static function init() {
        // Scripts
        if(!is_admin()) { // show only in public area
            add_action('wp_enqueue_scripts', array (
                'WP_MeteoSidebar',
                'enqueue_scripts'
            ));
            // shortcodes
            add_shortcode('meteo-sidebar', array (
                'WP_MeteoSidebar',
                'main'
            ));
        }
    }

    public static function enqueue_scripts() {
        wp_enqueue_script('wp-meteo-sidebar', plugins_url('static/js/meteo-sidebar.js', __FILE__), array (
            'jquery'
        ));
        wp_enqueue_style('wp-meteo-sidebar', plugins_url('static/css/default.css', __FILE__), array ());
    }

    /**
     * @param string $location
     * @return SimpleXMLElement
     */
    private static function getForecast($location) {
        try {
            $dir = plugin_dir_path(__FILE__) . "data";
            if(!file_exists($dir)) {
                mkdir($dir);
            }
            $dataFile = "{$dir}/data.json";
            $dataRequest = $location . "/forecast_hour_by_hour";
            $hash = md5($dataRequest);
            $resultFile = "{$dir}/{$hash}.xml";

            $data = array ();
            if(file_exists($dataFile)) {
                $data = json_decode(file_get_contents($dataFile), true);
                if($data [$hash] && file_exists($resultFile)) {
                    if($data [$hash] > (time() - 600)) {
                        $result = file_get_contents($resultFile);
                    }
                }
            }

            if(!$result) {
                file_put_contents($resultFile, file_get_contents("http://www.yr.no/place/{$dataRequest}.xml"));
                $data [$hash] = time();
                file_put_contents($dataFile, json_encode($data));
                $result = file_get_contents($resultFile);
            }
            return new SimpleXMLElement($result);
        } catch(Exception $e) {
        }
    }

    public static function main($args = array()) {
        $id = "meteo-sidebar" . time();
        $type = $args ["type"];
        if($type != "inline") {
            $type = "at-side";
        }
        if($args ["location"]) {
            $location = $args ["location"];
            $link = "http://www.yr.no/place/{$location}";
            return self::render($location, $link, $type);
        } else {
            if(class_exists("EM_Events")) {
                $events = EM_Events::get();
                /* @var $event EM_Event */
                events :
                foreach($events as $event) {
                    /* @var $location Em*/
                    if($location = $event->get_location()) {
                        if($location->location_attributes) {
                            foreach($location->location_attributes as $key => $value) {
                                if($key === "Place yr.no") {
                                    $link = "http://www.yr.no/place/{$value}";
                                    $place = $location->location_name;
                                    $closestTurnamentDate = date('j. n. Y', $event->start);
                                    return self::render($value, $link, $type, $place, $closestTurnamentDate);
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    /**
     * @param EM_Event $event
     * @return string
     */
    private static function render($placeId, $link, $type, $place = null, $closestTurnamentDate = null) {
        ob_start();
        if($type == "at-side") {
        ?>
<div class="meteo-sidebar at-side" <?= "data-place-id='{$placeId}'" ?>>
	<div class="bg">
		<div class="symbol">
			<img data-symbol />
        	<span data-temp />
		</div>
		<div class="content">
			<h3><?= $place ?></h3>
			<?php if($closestTurnamentDate) { ?>
            <div class="event">Tady hrajeme už <?= $closestTurnamentDate ?></div>
            <?php } ?>
			<a <?= "href='{$link}'" ?> target="_blank" data-link>
				<img class="logo" src="http://www.yr.no/assets/images/logo-yr-50.png" />
				právě teď je tu takhle
				<img draggable="false" class="emoji" alt="😉" src="https://s.w.org/images/core/emoji/2.2.1/svg/1f609.svg" />
			</a>
		</div>
	</div>
</div>
<?php
        } else if($type == "inline") {
?>
<div class="meteo-sidebar inline" <?= "data-place-id='{$placeId}'" ?>>
    <div class="symbol">
        <img data-symbol />
        <span data-temp />
    </div>
</div>
<?php
        }
        return ob_get_clean();
    }
}

add_action('plugins_loaded', array (
    'WP_MeteoSidebar',
    'init'
), 100);
